I**nesrt in the main body of the paper:**

We use the probabilistic programming language `PyAutoFit` https://github.com/rhayes777/PyAutoFit) [@pyautofit] to...

**At the end of the paper (delete as appropriate, see https://pyautofit.readthedocs.io/en/latest/general/citations.html):**

# Software Citations

This work uses the following software packages:

- `corner.py` https://github.com/dfm/corner.py [@corner]
- `dynesty` https://github.com/joshspeagle/dynesty [@dynesty]
- `emcee` https://github.com/dfm/emcee [@emcee]
- `matplotlib` https://github.com/matplotlib/matplotlib [@matplotlib]
- `NumPy` https://github.com/numpy/numpy [@numpy]
- `PyAutoFit` https://github.com/rhayes777/PyAutoFit [@pyautofit]
- `PyMultiNest` https://github.com/JohannesBuchner/PyMultiNest [@multinest] [@pymultinest]
- `PySwarms` https://github.com/ljvmiranda921/pyswarms [@pyswarms]
- `Python` https://www.python.org/ [@python]
- `Scipy` https://github.com/scipy/scipy [@scipy]
- `SQLite` https://www.sqlite.org/index.html [@sqlite]
- `UltraNest` https://github.com/JohannesBuchner/UltraNest [@ultranest]
- `Zeus` https://github.com/minaskar/zeus [@zeus1] [@zeus2]